@@ -100,29 +100,37 @@ class Zone():
             self._machine._machineId, self.base_zone, 13)
 
     # OPERATION ZONE MODE
-    def get_sleep_mode(self):
+    def is_sleep_mode(self):
         temp = bit_value(self._zone_state, 0, 0)
-        return OnOff(temp)
+        return bool(temp)
 
-    def get_zone_programing_mode(self):
+    def is_zone_programing_mode(self):
         temp = bit_value(self._zone_state, 0, 1)
-        return OnOff(temp)
+        return bool(temp)
 
-    def get_tacto_on(self):
+    def is_tacto_on(self):
         temp = bit_value(self._zone_state, 0, 2)
-        return OnOff(temp)
+        return bool(temp)
 
-    def get_zone_hold(self):
+    def is_zone_hold(self):
         temp = bit_value(self._zone_state, 0, 3)
-        return OnOff(temp)
+        return bool(temp)
 
     def get_speed_selection(self):
         temp = state_value(self._zone_state, 0, 4, 5)
         return FancoilSpeed(temp)
 
-    def get_zone_on_off(self):
+    def is_zone_on(self):
         temp = bit_value(self._zone_state, 0, 6)
-        return OnOff(temp)
+        return bool(temp)
+    
+    def turnon_zone(self):
+        new_value = change_bit_value(self._zone_state, 0, 6, 1)
+        self.write_register(0, new_value)
+    
+    def turnoff_zone(self):
+        new_value = change_bit_value(self._zone_state, 0, 6, 0)
+        self.write_register(0, new_value)
 
     def get_zone_mode(self):
         temp = state_value(self._zone_state, 0, 8, 10)
@@ -145,16 +153,14 @@ class Zone():
     
     def set_max_signal_value(self, value):
         if value >= 25 or value <= 30:
-            self.write_register(1, value * 10)
-        self.write_register(2, value * 10)
+            self.write_register(2, value * 10)
 
     def get_signal_temperature_value(self):
         return self._zone_state[3] / 10
     
     def set_signal_temperature_value(self, value):
         if value >= 18 or value <= 30:
-            self.write_register(1, value * 10)
-        self.write_register(3, value * 10)
+            self.write_register(3, int(value * 10))
 
     # ZONE CONFIGURATION
 
