@@ -2,12 +2,6 @@ from airzone.utils import *
 import logging
 from enum import Enum
 
-
-class OnOff(Enum):
-    OFF = 0
-    ON = 1
-
-
 class MachineOperationMode(Enum):
     STOP = 0
     COLD = 1
@@ -21,7 +15,7 @@ class ZoneMode(Enum):
     COLD = 1
     HOT_AIR = 2
     AIR = 3
-    FLOOT_HOT = 4
+    FLOOR_HOT = 4
     HOTPLUS = 5
 
 
@@ -76,10 +70,24 @@ class LocalFancoilType(Enum):
     FANCOIL = 1
 
 def state_value(state, address, init = 0, end = 15):
-    return shifting(pad_right_list(bitfield(state[address]),16,0)[init:end+1])
+    '''
+    init and end are included on the desired slice
+    '''
+    binary = format(state[address], '016b')
+    r_init = len(binary)-1-init
+    r_end = len(binary)-1-end + 1
+    kBitSubStr = binary[r_end : r_init]
+    return int(kBitSubStr, 2)
 
 def bit_value(state, address, bit):
-    return shifting(pad_right_list(bitfield(state[address]),16,0)[bit])
+    #return state_value(state, address, bit, bit)
+    temp = format(state[address], '016b')
+    return temp[len(temp)-1-bit]
+
+def change_bit_value(state, address, bit, value):
+    temp = format(state[address], '016b')
+    temp[len(temp)-1-bit] = value
+    return int(temp, 2)
 
 def date_as_number(date):
     l = bitfield(date.weekday() + 1)
